@@ -1,5 +1,10 @@
 #!/usr/bin/env python3
+from __future__ import annotations
+
 import logging
+from typing import TYPE_CHECKING
+
+from qolsys_controller.plugin import QolsysPlugin
 
 from .panel import QolsysPanel
 from .plugin_c4 import QolsysPluginC4
@@ -9,20 +14,27 @@ from .state import QolsysState
 
 LOGGER = logging.getLogger(__name__)
 
+if TYPE_CHECKING:
+    from .plugin import QolsysPlugin
+
 class QolsysController:
 
     def __init__(self) -> None:
 
         # QolsysController Information
-        self.plugin = None
-        self._state = QolsysState()
-        self._settings = QolsysSettings()
-        self._panel = QolsysPanel(settings=self.settings, state=self.state)
+        self._plugin: QolsysPlugin | None = None
+        self._state = QolsysState(self)
+        self._settings = QolsysSettings(self)
+        self._panel = QolsysPanel(self)
 
     @property
     def state(self) -> QolsysState:
         return self._state
 
+    @property
+    def plugin(self) -> QolsysPlugin:
+        return self._plugin
+
     @property
     def panel(self) -> QolsysPanel:
         return self._panel
@@ -37,13 +49,13 @@ class QolsysController:
 
             case "c4":
                 LOGGER.debug("C4 Plugin Selected")
-                self.plugin = QolsysPluginC4(self.state, self.panel, self.settings)
+                self._plugin = QolsysPluginC4(self)
                 return
 
             case "remote":
                 LOGGER.debug("Remote Plugin Selected")
-                self.plugin = QolsysPluginRemote(self.state, self.panel, self.settings)
+                self._plugin = QolsysPluginRemote(self)
                 return
 
             case _:
-                LOGGER.debug("Unknow Plugin Selected")
+                LOGGER.error("Unknow Plugin Selected")
